@@ -213,11 +213,6 @@ QFuture<VideoListResult> PeerTubeApi::requestFeed(Paginator *paginator)
     return requestVideoList(Feed, QStringLiteral(""), {}, paginator);
 }
 
-QFuture<VideoListResult> PeerTubeApi::requestTop()
-{
-    return requestVideoList(Top);
-}
-
 QFuture<VideoListResult> PeerTubeApi::requestTrending(TrendingTopic topic, Paginator *paginator)
 {
     QHash<QString, QString> parameters;
@@ -402,6 +397,11 @@ QFuture<Result> PeerTubeApi::removeVideoFromPlaylist(const QString &plid, const
     return {};
 }
 
+QString PeerTubeApi::getVideoUrl(const QString &videoId)
+{
+    return apiUrl(QStringLiteral("/w/%1").arg(videoId)).toString();
+}
+
 Error PeerTubeApi::invalidJsonError()
 {
     return {QNetworkReply::InternalServerError, i18n("Server returned no valid JSON.")};
